package me.yoqi.conf;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.Contact;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

import java.util.Collections;

/**
 * Created by liuyuqi on 9/21/2019.
 * Springfox 提供了一个 Docket 对象，让我们可以灵活的配置 Swagger 的各项属性
 * Configuration  Spring 语法，表示配置类
 */
@Configuration
@EnableSwagger2
public class SwaggerConfig {

    /**
     * 配置
     */
    @Bean
    public Docket api() {
        return new Docket(DocumentationType.SWAGGER_2).select().
                apis(RequestHandlerSelectors.any())
//                .apis(RequestHandlerSelectors.basePackage("me.yoqi.api.v2")) //只扫描该包下
                .paths(PathSelectors.any())
                .build()
                .apiInfo(apiInfo());
    }

    /**
     * Swagger api版本，版权，联系人等信息。
     */
    private ApiInfo apiInfo() {
        return new ApiInfo(
                "Spring Boot 项目集成 Swagger 实例文档",
                "我的博客网站：http://blog.yoqi.me，欢迎大家访问。",
                "API V1.0.1",
                "http://blog.yoqi.me/service",
                new Contact("lyq", "http://blog.yoqi.me", "liuyuqi.gov@msn.cn"),
                "Apache", "http://www.apache.org/", Collections.emptyList());
    }
}
