package me.yoqi;

import io.github.swagger2markup.GroupBy;
import io.github.swagger2markup.Language;
import io.github.swagger2markup.Swagger2MarkupConfig;
import io.github.swagger2markup.Swagger2MarkupConverter;
import io.github.swagger2markup.builder.Swagger2MarkupConfigBuilder;
import io.github.swagger2markup.markup.builder.MarkupLanguage;
import org.springframework.boot.autoconfigure.SpringBootApplication;

import java.net.MalformedURLException;
import java.net.URL;
import java.nio.file.Path;
import java.nio.file.Paths;

@SpringBootApplication
public class SwaggerHtmlGenerate {

    public static void main(String[] args) {
        new SwaggerHtmlGenerate().generateHtml();
    }

    /**
     * Generate html from swagger api docs.
     */
    private void generateHtml() {
        URL url = null;
        try {
            url = new URL("http://localhost:8080/v2/api-docs");
        } catch (MalformedURLException e) {
            throw new RuntimeException(e);
        }
        Path path = Paths.get("src/docs/docs/generated");

        Swagger2MarkupConfig config = new Swagger2MarkupConfigBuilder()
                .withMarkupLanguage(MarkupLanguage.MARKDOWN)
                .withOutputLanguage(Language.ZH)
                .withPathsGroupedBy(GroupBy.TAGS)
                .withGeneratedExamples()
                .withoutInlineSchema()
                .build();
        Swagger2MarkupConverter.from(url).withConfig(config).build().toFolder(path);
    }
}
